"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = require("fs");
const Unzipper_1 = require("../../../utils/Unzipper");
const move_1 = require("../../../utils/move");
class PrepareStrategy {
    constructor({ path }) {
        this.patterns = [
            '**/*',
            '!node_modules/**/*',
            '!build/**/*',
            '!.gitignore',
            '!.git/**/*',
            '!.ewizard/checksum.json',
        ];
        this.path = path;
    }
    static getPrepareStrategy(path) {
        return __awaiter(this, void 0, void 0, function* () {
            if (path.endsWith('.zip')) {
                return new PrepareFromArchive({ path });
            }
            else if ((yield fs_1.promises.lstat(path)).isDirectory()) {
                return new PrepareFromFolder({ path });
            }
        });
    }
}
exports.default = PrepareStrategy;
class PrepareFromFolder extends PrepareStrategy {
    execute(to, onProgressCallback = () => { }) {
        return __awaiter(this, void 0, void 0, function* () {
            yield (0, move_1.moveFolder)({ to, from: this.path, patterns: this.patterns }, onProgressCallback);
        });
    }
}
class PrepareFromArchive extends PrepareStrategy {
    execute(to, onProgressCallback = () => { }) {
        return __awaiter(this, void 0, void 0, function* () {
            yield new Unzipper_1.default(this.path).unzip(to, { patterns: this.patterns }, onProgressCallback);
        });
    }
}
//# sourceMappingURL=PrepareStrategy.js.map