"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const checksum = require("checksum");
const upath_1 = require("@ewizardjs/upath");
const util_1 = require("util");
const globby = require("globby");
const Checksums_1 = require("./Checksums");
const getChecksum = (0, util_1.promisify)(checksum.file);
const ignorePatterns = [
    '!**/demo',
    '!node_modules/**/**',
    '!**/node_modules/**/**',
    '!**/*.md',
    '!**/.DS_Store',
    '!**/*changelog*',
    '!**/*.zip',
    '!**/LICENSE',
];
class CheckSumsGenerator {
    static calculate(directoryPath) {
        return __awaiter(this, void 0, void 0, function* () {
            const result = new Checksums_1.default();
            const files = yield this.getFiles(directoryPath);
            for (const file of files) {
                const checksum = yield getChecksum(file);
                const relativePath = (0, upath_1.toUnix)((0, upath_1.relative)(directoryPath, file));
                result.add(relativePath, checksum);
            }
            return result;
        });
    }
    static getFiles(directoryPath) {
        return globby(['**/**', ...ignorePatterns], { cwd: directoryPath, absolute: true });
    }
}
exports.default = CheckSumsGenerator;
//# sourceMappingURL=index.js.map